@@ -66,6 +66,9 @@ namespace Breeze
     class SplitterFactory;
     class WidgetExplorer;
     class WindowManager;
+    #if !BREEZE_USE_KDE4
+    class BlurHelper;
+    #endif
 
     //* convenience typedef for base class
     #if BREEZE_USE_KDE4
@@ -497,6 +500,11 @@ namespace Breeze
         //* keyboard accelerators
         Mnemonics* _mnemonics = nullptr;
 
+        #if !BREEZE_USE_KDE4
+        //* blur helper
+        BlurHelper* _blurHelper = nullptr;
+        #endif
+
         //* window manager
         WindowManager* _windowManager = nullptr;
 
